@@ -165,7 +165,7 @@ def render_dot_html(self, node, code, options, prefix='blockdiag',
         relfn, outfn = get_image_filename(self, code, options, prefix)
 
         image = create_blockdiag(self, code, options, prefix)
-        image.save(outfn, 'PNG')
+        image.save(outfn)
 
         # generate description table
         descriptions = []
@@ -183,8 +183,8 @@ def render_dot_html(self, node, code, options, prefix='blockdiag',
                                                 options, thumb_prefix)
 
             thumb_size = (options['maxwidth'], image_size[1])
-            image.save(toutfn, 'PNG', thumb_size)
-            thumb_size = image.image.size
+            image.save(toutfn, thumb_size)
+            thumb_size = image.drawer.image.size
 
     except BlockdiagError, exc:
         self.builder.warn('dot code %r: ' % code + str(exc))
